{% extends 'account/profile/base.html' %} {% load i18n thumbnail %} {% block content %}

## {% trans 'Мої замовлення' %}

{% if order_items %}

# | {% trans 'Дата' %} | {% trans 'К-сть товарів' %} | {% trans 'Сума' %} | {% trans 'Статус' %} | {% trans 'Звіт' %}
--- | --- | --- | --- | --- | ---
{% for item in order_items %}
{{ item.id }} | {{ item.date_created }} | {{ item.product_count }} | {{ item.printable_total }} | {{ item.get_status_display }} | {% trans 'Завантажити звіт' %}
{% endfor %}

{% else %}
{% trans 'У Вас поки немає замовлень' %}
{% endif %}
{% endblock %}